package VMOMI::HostProfileManagerTaskListRequirement;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
